@@ -41,7 +41,7 @@ use strict;
 ##==============================================================================
 ## Globals & Constants
 
-our $VERSION = "0.12.003";
+our $VERSION = "0.12.004";
 our @ISA = qw(DiaColloDB::Client);
 
 ## $PGOOD_DEFAULT
@@ -2295,7 +2295,7 @@ sub profileOptions {
   $opts->{slice}   //= 1;
   $opts->{groupby} ||= join(',', map {quotemeta($_)} @{$that->attrs}) if (ref($that));
   $opts->{score}   //= 'f';
-  $opts->{eps}     //= 0;
+  $opts->{eps}     //= 0; #0.5;
   $opts->{kbest}   //= -1;
   $opts->{cutoff}  //= '';
   $opts->{global}  //= 0;
